function output = nn_test(datain, nn)
%function output = rbf_test(datain, rbf)
% 
% Restituisce l'output di una approssimatore Nearest Neighbors.
%
% datain: matrice [n m] dei dati di input; 
%        n e' il numero di dati di input, m e' la dimensione dello 
%        spazio di input.
%        m deve essere coerente con rbf.centri (m = size(rbf.centri,2)).
% nn: struttura che contiene i parametri della rete; in particolare,
% contiene:
% - in: matrice [num_gauss m]
% - out: vettore [n k] dei dati di output.
%
% output: vettore [n k] dei dati di output.
%
% Vedi anche: nn_train
%
  
  num_dati = size(datain, 1);
  dim_input = size(datain, 2);
  if (num_dati == 0 | dim_input == 0),
    disp(['NN_TEST: matrice di input non adatta (n =' int2str(num_dati) ...
         ', m = ' int2str(dim_input) ')']);
    disp('"help nn_test" per maggiori informazioni.');
    return;    
  end;
  
  if (dim_input ~= size(nn.in, 2)),
    disp(['NN_TEST: dimensione di input (' int2str(size(nn.in, 2))...
          ') diversa da m (' int2str(dim_input) ')']);
    disp('"help nn_test" per maggiori informazioni.');
    return;    
  end;

  num_samples = size(nn.in, 1);
  % G e' la matrice delle uscite delle unita'

  dist=sum((nn.in-ones(num_samples,1)*datain).^2,2);
  
  [v p] = min(dist);
  output = nn.out(p, :);
